@@ -9,8 +9,6 @@ library(ggplot2)
 library(Matching)
 library(WeightIt)
 library(prodlim)
-library(survtmle)
-library(R6)
 library(MASS)
 library(tidyr)
 library(riskRegression)
@@ -19,7 +17,6 @@ library(geepack)
 library(nnet)
 library(cmprsk)
 library(eventglm)
-library(SuperLearner)
 library(rmarkdown)
 library(mice)
 
