@@ -12,8 +12,7 @@ test_that("not an adjustedsurv object", {
                                      from=0,
                                      to=1,
                                      conf_int=FALSE,
-                                     difference=FALSE,
-                                     ratio=FALSE),
+                                     contrast="none"),
                paste0("'adjsurv' must be an 'adjustedsurv' object ",
                       "created using the 'adjustedsurv()' function."),
                fixed=TRUE)
@@ -24,8 +23,7 @@ test_that("from smaller 0", {
                                      from=-10,
                                      to=1,
                                      conf_int=FALSE,
-                                     difference=FALSE,
-                                     ratio=FALSE),
+                                     contrast="none"),
                "'from' and 'to' must be >= 0.")
 })
 
@@ -34,8 +32,7 @@ test_that("from wrong format", {
                                      from="0",
                                      to=1,
                                      conf_int=FALSE,
-                                     difference=FALSE,
-                                     ratio=FALSE),
+                                     contrast="none"),
                "'from' and 'to' must be numbers (one for each argument).",
                fixed=TRUE)
 })
@@ -45,8 +42,7 @@ test_that("from not smaller than to", {
                                      from=0,
                                      to=0,
                                      conf_int=FALSE,
-                                     difference=FALSE,
-                                     ratio=FALSE),
+                                     contrast="none"),
                "'from' must be smaller than 'to'.")
 })
 
@@ -55,27 +51,16 @@ test_that("conf_int wrong format", {
                                      from=0,
                                      to=1,
                                      conf_int=1,
-                                     difference=FALSE,
-                                     ratio=FALSE),
+                                     contrast="none"),
                "'conf_int' must be either TRUE or FALSE.")
 })
 
-test_that("cannot use both difference and ratio", {
-  expect_warning(check_inputs_adj_rmst(adjsurv=adjsurv,
-                                       from=0,
-                                       to=1,
-                                       conf_int=FALSE,
-                                       difference=TRUE,
-                                       ratio=TRUE))
-})
-
 test_that("no extrapolation allowed", {
   expect_error(check_inputs_adj_rmst(adjsurv=adjsurv,
                                      from=0,
                                      to=200,
                                      conf_int=FALSE,
-                                     difference=FALSE,
-                                     ratio=FALSE),
+                                     contrast="none"),
                "'to' cannot be greater than the latest observed time.")
 })
 
@@ -84,8 +69,7 @@ test_that("no bootstrapping performed", {
                                        from=0,
                                        to=1,
                                        conf_int=TRUE,
-                                       difference=FALSE,
-                                       ratio=FALSE),
+                                       contrast="none"),
                paste0("Cannot use bootstrapped estimates because they ",
                       "were not estimated. Need 'bootstrap=TRUE' in ",
                       "'adjustedsurv' function call."))
@@ -99,8 +83,7 @@ test_that("too little points in time", {
                                        from=0,
                                        to=1,
                                        conf_int=FALSE,
-                                       difference=FALSE,
-                                       ratio=FALSE),
+                                       contrast="none"),
                  paste0("Using only a few points in time might lead to ",
                         "biased estimates. Consider using a finer ",
                         "times grid in 'adjustedsurv'."))
