@@ -1147,59 +1147,3 @@ test_that("wrong censoring_model with mira", {
                       "be supplied to 'censoring_model' instead of ",
                       "single models. See documentation."))
 })
-
-test_that("warning with missing values in variable", {
-  expect_warning(check_inputs_adjustedcif(data=mids_na_group,
-                                          variable="group",
-                                          ev_time="time",
-                                          event="event",
-                                          method="aalen_johansen",
-                                          conf_int=TRUE,
-                                          conf_level=0.95,
-                                          times=NULL,
-                                          bootstrap=FALSE,
-                                          n_boot=2,
-                                          cause=1,
-                                          na.action="na.omit",
-                                          clean_data=TRUE),
-                 paste0("Using multiple imputation with missing values in ",
-                        "'variable' has not been tested yet. ",
-                        "Use with caution."))
-})
-
-test_that("warning with missing values in ev_time", {
-  expect_warning(check_inputs_adjustedcif(data=mids_na_time,
-                                          variable="group",
-                                          ev_time="time",
-                                          event="event",
-                                          method="aalen_johansen",
-                                          conf_int=TRUE,
-                                          conf_level=0.95,
-                                          times=NULL,
-                                          bootstrap=FALSE,
-                                          n_boot=2,
-                                          cause=1,
-                                          na.action="na.omit",
-                                          clean_data=TRUE),
-    paste0("Using multiple imputation with missing values in 'ev_time' ",
-           "variable has not been tested yet. Use with caution."))
-})
-
-test_that("warning with missing values in event", {
-  expect_warning(check_inputs_adjustedcif(data=mids_na_event,
-                                          variable="group",
-                                          ev_time="time",
-                                          event="event",
-                                          method="aalen_johansen",
-                                          conf_int=TRUE,
-                                          conf_level=0.95,
-                                          times=NULL,
-                                          bootstrap=FALSE,
-                                          n_boot=2,
-                                          cause=1,
-                                          clean_data=TRUE,
-                                          na.action="na.omit"),
-                 paste0("Using multiple imputation with missing values ",
-                        "in 'event' variable has not been tested yet. ",
-                        "Use with caution."))
-})
